diff --git a/ChangeLog b/ChangeLog
index ccd891f927ec2417389fba761af1716a16f2a441..b3315e6916f5a16d997bc5e9271d6b16d05ff046 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -25,6 +25,8 @@ CVS code -
 	  we cut the line, we hit End to move to the end of the line
 	  after it. (DLR)
 - files.c:
+  read_line()
+	- Rename variable prev to prevnode to avoid confusion. (DLR)
   load_open_file()
 	- Remove an unneeded clearok(FALSE). (DLR)
   get_next_filename()
diff --git a/src/proto.h b/src/proto.h
index 14a27908a4b9c5cb031be589411215e917b2d013..4d16a9a265ae8814b38b16a413508b604a5d8afd 100644
--- a/src/proto.h
+++ b/src/proto.h
@@ -237,8 +237,8 @@ void do_uncut_text(void);
 
 /* Public functions in files.c. */
 void new_file(void);
-filestruct *read_line(char *buf, filestruct *prev, bool *first_line_ins,
-	size_t len);
+filestruct *read_line(char *buf, filestruct *prevnode, bool
+	*first_line_ins, size_t len);
 void load_file(void);
 void read_file(FILE *f, const char *filename);
 int open_file(const char *filename, bool newfie, FILE **f);
diff --git a/src/files.c b/src/files.c
index 7e4eb71874370608106532017895a1ac4d9ecdaa..43d5eb0c05220be9f24e1fd6188f3e3d66e62eeb 100644
--- a/src/files.c
+++ b/src/files.c
@@ -61,10 +61,10 @@ void new_file(void)
 
 /* We make a new line of text from buf.  buf is length len.  If
  * first_line_ins is TRUE, then we put the new line at the top of the
- * file.  Otherwise, we assume prev is the last line of the file, and
- * put our line after prev. */
-filestruct *read_line(char *buf, filestruct *prev, bool *first_line_ins,
-	size_t len)
+ * file.  Otherwise, we assume prevnode is the last line of the file,
+ * and put our line after prevnode. */
+filestruct *read_line(char *buf, filestruct *prevnode, bool
+	*first_line_ins, size_t len)
 {
     filestruct *fileptr = (filestruct *)nmalloc(sizeof(filestruct));
 
@@ -99,12 +99,12 @@ filestruct *read_line(char *buf, filestruct *prev, bool *first_line_ins,
 	    filebot = fileptr;
 	fileage = fileptr;
     } else {
-	assert(prev != NULL);
+	assert(prevnode != NULL);
 
-	fileptr->prev = prev;
+	fileptr->prev = prevnode;
 	fileptr->next = NULL;
-	fileptr->lineno = prev->lineno + 1;
-	prev->next = fileptr;
+	fileptr->lineno = prevnode->lineno + 1;
+	prevnode->next = fileptr;
     }
 
     return fileptr;